@@ -1,9 +1,9 @@
-context("Helper functions")
-
-
 ## General helpers
 test_that("General helpers", {
-  expect_true(identical(rcites_timestamp("2017-01-01"), "2017-01-01T00:00:00"))
+  expect_identical(
+      rcites_timestamp("2017-01-01"),
+       utils::URLencode("2017-01-01T00:00:00", reserved = TRUE)
+     )
   expect_true(is.null(rcites_lang("en")))
   expect_true(identical(rcites_lang("fr"), "language=fr"))
   expect_error(rcites_lang("wrong"))
@@ -11,9 +11,12 @@ test_that("General helpers", {
   expect_true(identical(rcites_scope("all"), "scope=all"))
   expect_error(rcites_scope("wrong"))
   expect_warning(rcites_checkid("1wrong234"))
+  expect_identical(
+    rcites_taxonconcept_request(tx_nm, "CITES", FALSE, 1, 500, NULL, NULL),
+    "https://api.speciesplus.net/api/v1/taxon_concepts.json?name=Loxodonta%20africana&page=1&per_page=500"
+  )
 })
 
-
 ## Base URL
 pag <- list(per_page = 500, total_entries = 501)
 
@@ -24,7 +27,6 @@ test_that("Base URL", {
   expect_error(set_token(""), "No token has been provided.")
 })
 
-
 ## Outputs helpers
 ls_ex <- rcites_null_to_na(list("A", list("A", NULL)))
 df1 <- data.frame(is_current = c(1, 0), wrong = letters[1:2])
@@ -35,7 +37,7 @@ test_that("Outputs helpers", {
   expect_true(all(res1$is_current == c(TRUE, FALSE)))
 })
 
-## Prin helpers
+## Print helpers
 str <- paste(letters[1:26], collapse = "")
 str2 <- paste(letters[1:25], collapse = "")
 rcites_print_shorten(str)
@@ -46,3 +48,5 @@ test_that("Print helpers", {
   expect_equal(rcites_print_shorten(str, 4), "abcd [truncated]")
   expect_output(rcites_print_df(data.frame(id = 1)), "  id\\n1  1")
 })
+
+
